Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(5226)

Unified Diff: cc/CCSingleThreadProxy.h

Issue 10920059: Rolls cc and webkit_compositor up to 127340 (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 8 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « cc/CCPrioritizedTextureTest.cpp ('k') | cc/CCThreadProxy.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: cc/CCSingleThreadProxy.h
diff --git a/cc/CCSingleThreadProxy.h b/cc/CCSingleThreadProxy.h
index 37a970c3b3f7ddf62ff281bca000ba944589a48e..02981d1026c8717836802ed4aca9c1a6af5f15e5 100644
--- a/cc/CCSingleThreadProxy.h
+++ b/cc/CCSingleThreadProxy.h
@@ -82,7 +82,7 @@ private:
};
// For use in the single-threaded case. In debug builds, it pretends that the
// code is running on the thread to satisfy assertion checks.
class DebugScopedSetImplThread {
public:
DebugScopedSetImplThread()
@@ -117,6 +117,15 @@ public:
}
};
+// For use in the single-threaded case. In debug builds, it pretends that the
+// code is running on the impl thread and that the main thread is blocked to
+// satisfy assertion checks
+class DebugScopedSetImplThreadAndMainThreadBlocked {
+private:
+ DebugScopedSetImplThread m_implThread;
+ DebugScopedSetMainThreadBlocked m_mainThreadBlocked;
+};
+
} // namespace WebCore
#endif
« no previous file with comments | « cc/CCPrioritizedTextureTest.cpp ('k') | cc/CCThreadProxy.cpp » ('j') | no next file with comments »
@@ -82,7 +82,7 @@ private:
};
// For use in the single-threaded case. In debug builds, it pretends that the
-// code is running on the thread to satisfy assertion checks.
+// code is running on the impl thread to satisfy assertion checks.
class DebugScopedSetImplThread {
public:

Powered by Google App Engine
This is Rietveld 408576698